<?php
namespace Teknisa\MAN\Controllers;


use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Teknisa\MAN\Utilities;
use Zeedhi\Framework\Util\Functions;

class ValoresOperador extends CrudWithParameterBag {
    protected $dataSourceName = 'vnd02300_valoresarrecadadosoperador';
    protected $parameterBagColumns = array('CDFILIAL', 'TCDOPERADOR', 'DATAINI', 'DATAFIN', 'CDOPERADOR');
    protected $utilService;

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, Utilities\Util $utilService) {
        $this->utilService = $utilService;
        parent::__construct($dataSourceManager, $parameterBag);
        
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        
        $conditions = $this->utilService->getParamsAsArray($request);
        
        if(Functions::arrayKeyExists('DTMOVIMCAIXA', $conditions) ) {
        
            $conditions['DATAINI'] = $conditions['DTMOVIMCAIXA'][0];
            $conditions['DATAFIN'] = $conditions['DTMOVIMCAIXA'][1];
            
            unset($conditions['DTMOVIMCAIXA']);
        }
        
        if( !Functions::arrayKeyExists('CDFILIAL', $conditions) ) {
            $conditions['CDFILIAL'] = null;
        }
        
        if( !Functions::arrayKeyExists('CDOPERADOR', $conditions) ) {
            $conditions['CDOPERADOR'] = null;
        }
        
        if( Functions::arrayKeyExists('NMOPERADOR_V', $conditions) ) {
            $conditions['CDOPERADOR'] = implode('_', $conditions['NMOPERADOR_V']);
            unset($conditions['NMOPERADOR_V']);
            $conditions['TCDOPERADOR'] = 'F';   
        }  else {
            $conditions['TCDOPERADOR'] = 'T';    
        }
        
        if(Functions::arrayKeyExists('NMOPERADOR_V', $conditions)) {
            unset($conditions['NMOPERADOR_V']);
        }
        
        $dataSourceFilter = array();
        
        foreach($conditions as $key => $value) {
            $dataSourceFilter[] = $condition = array(
                "columnName" => $key,
                "operator"=> "=",
                "value"=> $value
            );
        }
        
        $original = $request->getFilterCriteria()->getConditions();
            
        for($i = 0 ; $i < count($dataSourceFilter) ; $i++) {
            for($j = 0 ; $j < count($original) ; $j++ ) {
                if( $dataSourceFilter[$i]['columnName'] === $original[$j]['columnName'] &&
                    $dataSourceFilter[$i]['operator'] !== $original[$j]['operator'])  {
                    $dataSourceFilter[$i]['operator'] = $original[$j]['operator'];
                }
                
            }
        }
        $newRequest = new DTO\Request\Filter(
            new FilterCriteria(
                $request->getFilterCriteria()->getDataSourceName(),
                $dataSourceFilter,
                $request->getFilterCriteria()->getPage(),
                $request->getFilterCriteria()->getPageSize()
            ),
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        );
        
        parent::find($newRequest, $response);
    }
}